@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/kms/KMS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kms/KMS_EXPORTS.h>
 
-namespace Aws
-{
-namespace KMS
-{
-namespace Model
-{
-  enum class ExpirationModelType
-  {
-    NOT_SET,
-    KEY_MATERIAL_EXPIRES,
-    KEY_MATERIAL_DOES_NOT_EXPIRE
-  };
+namespace Aws {
+namespace KMS {
+namespace Model {
+enum class ExpirationModelType { NOT_SET, KEY_MATERIAL_EXPIRES, KEY_MATERIAL_DOES_NOT_EXPIRE };
 
-namespace ExpirationModelTypeMapper
-{
+namespace ExpirationModelTypeMapper {
 AWS_KMS_API ExpirationModelType GetExpirationModelTypeForName(const Aws::String& name);
 
 AWS_KMS_API Aws::String GetNameForExpirationModelType(ExpirationModelType value);
-} // namespace ExpirationModelTypeMapper
-} // namespace Model
-} // namespace KMS
-} // namespace Aws
+}  // namespace ExpirationModelTypeMapper
+}  // namespace Model
+}  // namespace KMS
+}  // namespace Aws
