@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class ObjectLockMode
-  {
-    NOT_SET,
-    GOVERNANCE,
-    COMPLIANCE
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class ObjectLockMode { NOT_SET, GOVERNANCE, COMPLIANCE };
 
-namespace ObjectLockModeMapper
-{
+namespace ObjectLockModeMapper {
 AWS_S3CRT_API ObjectLockMode GetObjectLockModeForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForObjectLockMode(ObjectLockMode value);
-} // namespace ObjectLockModeMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace ObjectLockModeMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
