@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class ReplicationRuleStatus
-  {
-    NOT_SET,
-    Enabled,
-    Disabled
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class ReplicationRuleStatus { NOT_SET, Enabled, Disabled };
 
-namespace ReplicationRuleStatusMapper
-{
+namespace ReplicationRuleStatusMapper {
 AWS_S3CRT_API ReplicationRuleStatus GetReplicationRuleStatusForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForReplicationRuleStatus(ReplicationRuleStatus value);
-} // namespace ReplicationRuleStatusMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace ReplicationRuleStatusMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
