@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class RequestPayer
-  {
-    NOT_SET,
-    requester
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class RequestPayer { NOT_SET, requester };
 
-namespace RequestPayerMapper
-{
+namespace RequestPayerMapper {
 AWS_S3CRT_API RequestPayer GetRequestPayerForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForRequestPayer(RequestPayer value);
-} // namespace RequestPayerMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace RequestPayerMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
